Index: apps/app_confbridge.c
===================================================================
--- apps/app_confbridge.c	(revision 368848)
+++ apps/app_confbridge.c	(working copy)
@@ -755,7 +755,7 @@
 				continue;
 			}
 			/* only unmute them if they are not supposed to start muted */
-			if (!ast_test_flag(&other_conference_bridge_user->u_profile, USER_OPT_STARTMUTED)) {
+			if (!other_conference_bridge_user->mute_forced) {
 				other_conference_bridge_user->features.mute = 0;
 			}
 		}
@@ -1074,6 +1074,10 @@
 					other_participant->playing_moh = 1;
 					ast_bridge_unsuspend(conference_bridge->bridge, other_participant->chan);
 				}
+				/* If users are left in the conference that don't require a marked user and aren't muted, be sure to unumte them */
+				if (!ast_test_flag(&other_participant->u_profile, USER_OPT_WAITMARKED) && !other_participant->mute_forced && !other_participant->kicked) {
+					other_participant->features.mute = 0;
+				}
 			}
 		} else if (conference_bridge->users == 1) {
 			/* Of course if there is one other person in here we may need to start up MOH on them */
@@ -1306,6 +1310,12 @@
 	return 0;
 }
 
+static void user_set_mute_forced(int mute, struct conference_bridge_user *conference_bridge_user)
+{
+	conference_bridge_user->features.mute = mute;
+	conference_bridge_user->mute_forced = mute;
+}
+
 /*! \brief The ConfBridge application */
 static int confbridge_exec(struct ast_channel *chan, const char *data)
 {
@@ -1429,7 +1439,7 @@
 
 	/* If the caller should be joined already muted, make it so */
 	if (ast_test_flag(&conference_bridge_user.u_profile, USER_OPT_STARTMUTED)) {
-		conference_bridge_user.features.mute = 1;
+		user_set_mute_forced(1, &conference_bridge_user);
 	}
 
 	if (ast_test_flag(&conference_bridge_user.u_profile, USER_OPT_DROP_SILENCE)) {
@@ -1551,7 +1561,7 @@
 {
 	/* Mute or unmute yourself, note we only allow manipulation if they aren't waiting for a marked user or if marked users exist */
 	if (!ast_test_flag(&conference_bridge_user->u_profile, USER_OPT_WAITMARKED) || conference_bridge->markedusers) {
-		conference_bridge_user->features.mute = (!conference_bridge_user->features.mute ? 1 : 0);
+		user_set_mute_forced(!conference_bridge_user->features.mute ? 1 : 0, conference_bridge_user);
 		ast_test_suite_event_notify("CONF_MUTE", "Message: participant %s %s\r\nConference: %s\r\nChannel: %s", chan->name, conference_bridge_user->features.mute ? "muted" : "unmuted", conference_bridge_user->b_profile.name, chan->name);
 	}
 	return ast_stream_and_wait(chan, (conference_bridge_user->features.mute ?
@@ -2001,7 +2011,7 @@
 }
 
 /* \internal
- * \brief finds a conference user by channel name and mutes/unmutes them.
+ * \brief finds a conference user by channel name and forcibly mutes/unmutes them.
  *
  * \retval 0 success
  * \retval -1 conference not found
@@ -2025,7 +2035,7 @@
 		}
 	}
 	if (participant) {
-		participant->features.mute = mute;
+		user_set_mute_forced(mute, participant);
 		ast_test_suite_event_notify("CONF_MUTE", "Message: participant %s %s\r\nConference: %s\r\nChannel: %s", participant->chan->name, participant->features.mute ? "muted" : "unmuted", bridge->b_profile.name, participant->chan->name);
 	} else {
 		res = -2;;
Index: apps/confbridge/include/confbridge.h
===================================================================
--- apps/confbridge/include/confbridge.h	(revision 368848)
+++ apps/confbridge/include/confbridge.h	(working copy)
@@ -221,6 +221,7 @@
 	struct ast_bridge_tech_optimizations tech_args; /*!< Bridge technology optimizations for talk detection */
 	unsigned int kicked:1;                       /*!< User has been kicked from the conference */
 	unsigned int playing_moh:1;                  /*!< MOH is currently being played to the user */
+	unsigned int mute_forced:1;                  /*!< Mute has been forcibly set, not just as a result of waiting for marked users */
 	AST_LIST_ENTRY(conference_bridge_user) list; /*!< Linked list information */
 };
 
